==> service.nextup.notification-1.0.8.zip: service.nextup.notification/README.md <==
This addon shows a popup next up notification automatically to prompt for playing the next unwatched episode.

Configuration:

  - The addon is found in the services section and allows the notification time to be adjusted (default 30 seconds before the end)
  - The default action (ie Play/Do not Play) when nothing is pressed can also be configured
  - The number of episodes played in a row with no intervention to bring up the still watching window can be adjusted.
 
Skinners:

  - There is a script-nextup-notification-NextUpInfo.xml and script-nextup-notification-StillWatchingInfo.xml file located in default/1080i/ simply copy this to your skin folder and adjust it how you like it. 
  
      Controls Available:
  
      - script-nextup-notification-NextUpInfo.xml
          - 3000 - Title
          - 3001 - Plot
          - 3002 - Season/Episode
          - 3003 - Rating
          - 3004 - First Aired
          - 3005 - TV Show Fanart 
          - 3006 - TV Show ClearArt
          - 3008 - Episode Thumb
          - 3009 - TV Show Poster
          - 3010 - TV Show Landscape
          - 3011 - Video Resolution
          - 3012 - Watch Now Button
          - 3013 - Cancel Button
          - 3015 - Season Number
          - 3016 - Episode Number
          
      - script-nextup-notification-StillWatchingInfo.xml
          - 4000 - Label
          - 4001 - TV Show Poster
          - 4002 - Episode Thumb
          - 4003 - Rating
          - 4004 - First Aired
          - 4005 - TV Show Landscape
          - 4006 - Plot
          - 4007 - TV Show Fanart
          - 4008 - Season Number
          - 4009 - Episode Number
          - 4010 - Title
          - 4011 - Video Resolution
          - 4012 - Continue Watching Button
          - 4013 - Cancel Button
          - 4014 - TV Show ClearArt

==> service.nextup.notification-1.0.19.zip: service.nextup.notification/README.md <==
This addon shows a popup next up notification automatically to prompt for playing the next unwatched episode.

Configuration:

  - The addon is found in the services section and allows the notification time to be adjusted (default 30 seconds before the end)
  - The default action (ie Play/Do not Play) when nothing is pressed can also be configured
  - The number of episodes played in a row with no intervention to bring up the still watching window can be adjusted.
 
Skinners:

  - There is a script-nextup-notification-NextUpInfo.xml and script-nextup-notification-StillWatchingInfo.xml file located in default/1080i/ simply copy this to your skin folder and adjust it how you like it. 
  
      Controls Available:
  
      - script-nextup-notification-NextUpInfo.xml
          - 3000 - Title
          - 3001 - Plot
          - 3002 - Season/Episode
          - 3003 - Rating
          - 3004 - First Aired
          - 3005 - TV Show Fanart 
          - 3006 - TV Show ClearArt
          - 3008 - Episode Thumb
          - 3009 - TV Show Poster
          - 3010 - TV Show Landscape
          - 3011 - Video Resolution
          - 3012 - Watch Now Button
          - 3013 - Cancel Button
          - 3015 - Season Number
          - 3016 - Episode Number
          - 3018 - Play Count
          
      - script-nextup-notification-StillWatchingInfo.xml
          - 4000 - Label
          - 4001 - TV Show Poster
          - 4002 - Episode Thumb
          - 4003 - Rating
          - 4004 - First Aired
          - 4005 - TV Show Landscape
          - 4006 - Plot
          - 4007 - TV Show Fanart
          - 4008 - Season Number
          - 4009 - Episode Number
          - 4010 - Title
          - 4011 - Video Resolution
          - 4012 - Continue Watching Button
          - 4013 - Cancel Button
          - 4014 - TV Show ClearArt
          - 4018 - Play Count

      - script-nextup-notification-UnwatchedInfo.xml
          - 5000 - Label
          - 5001 - Plot
          - 5002 - Season/Episode
          - 5003 - Rating
          - 5004 - Clear Logo
